@@ -13,6 +13,7 @@ from robocorp_ls_core.lsp import (
     CodeLensTypedDict,
     DocumentSymbolTypedDict,
     PositionTypedDict,
+    LocationTypedDict,
 )
 from robotframework_ls.impl.protocols import IKeywordFound
 from robocorp_ls_core.watchdog_wrapper import IFSObserver
@@ -384,6 +385,16 @@ class RobotFrameworkServerApi(PythonLanguageServer):
             )
             return []
 
+        if formatter == OPTION_ROBOT_CODE_FORMATTER_BUILTIN_TIDY:
+            try:
+                from robot.tidy import Tidy
+            except ImportError:
+                # It's not available in newer versions of RobotFramework.
+                from robot import get_version
+
+                if int(get_version(naked=True).split(".")[0]) >= 5:
+                    formatter = OPTION_ROBOT_CODE_FORMATTER_ROBOTIDY
+
         if formatter == OPTION_ROBOT_CODE_FORMATTER_BUILTIN_TIDY:
             from robotframework_ls.impl.formatting import robot_source_format
 
@@ -411,7 +422,13 @@ class RobotFrameworkServerApi(PythonLanguageServer):
             else:
                 dirname = os.path.dirname(path)
 
-            new_contents = robot_tidy_source_format(ast, dirname)
+            try:
+                new_contents = robot_tidy_source_format(ast, dirname)
+            except ImportError:
+                log.critical(
+                    "Unable to code-format because robotidy could not be imported."
+                )
+                return []
 
         if new_contents is None or new_contents == text:
             return []
@@ -564,6 +581,28 @@ class RobotFrameworkServerApi(PythonLanguageServer):
 
         return hover(completion_context)
 
+    def m_references(
+        self, doc_uri: str, line: int, col: int, include_declaration: bool
+    ):
+        func = partial(
+            self._threaded_references, doc_uri, line, col, include_declaration
+        )
+        func = require_monitor(func)
+        return func
+
+    def _threaded_references(
+        self, doc_uri: str, line, col, include_declaration: bool, monitor: IMonitor
+    ) -> Optional[List[LocationTypedDict]]:
+        from robotframework_ls.impl.references import references
+
+        completion_context = self._create_completion_context(
+            doc_uri, line, col, monitor
+        )
+        if completion_context is None:
+            return None
+
+        return references(completion_context, include_declaration=include_declaration)
+
     def m_workspace_symbols(self, query: Optional[str] = None):
         func = partial(self._threaded_workspace_symbols, query)
         func = require_monitor(func)
