@@ -751,6 +751,20 @@ class Document(object):
         for text_edit in reversed(text_edits):
             self._apply_change(text_edit["range"], text_edit["newText"])
 
+    def find_line_with_contents(self, contents: str) -> int:
+        """
+        :param contents:
+            The contents to be found.
+
+        :return:
+            The 0-based index of the contents.
+        """
+        for i, line in enumerate(self.iter_lines()):
+            if contents in line:
+                return i
+        else:
+            raise AssertionError(f"Did not find >>{contents}<< in doc.")
+
     def __typecheckself__(self) -> None:
         from robocorp_ls_core.protocols import check_implements
 
