@@ -21,4 +21,14 @@ class _Visitor(ast.NodeVisitor):
 
 def ast_to_code(node):
     v = _Visitor(node)
+    for i, txt in enumerate(reversed(v.text)):
+        if not txt.strip():
+            continue
+        else:
+            break
+
+    if i > 0:
+        v.text = v.text[:-i]
+        v.text.append("\n")
+
     return "".join(v.text)
